@@ -40,7 +40,7 @@ def get_source(filename):
     path = os.path.join(cfg["templates_dir"], filename)
     return open(path).read()
 
-def get_template(filename):
+def get_template(filename, klass=jsontemplate.Template):
     """ Returns a template object.
 
     :param filename:
@@ -49,7 +49,7 @@ def get_template(filename):
     t = _cache.get(filename)
     if t and t._uptodate():
         return t
-    t = _cache[filename] = jsontemplate.Template(get_source(filename))
+    t = _cache[filename] = klass(get_source(filename))
     mtime = _mtime(filename)
     t._uptodate = lambda: _mtime(filename) == mtime
     return t
